build_object_paths

Function build_object_paths 

fn build_object_paths(
    planned_project: &Project,
    project_root: &Path,
) -> BTreeMap<ObjectId, PathBuf>
Reconstructs source file paths for planned objects under models/.

These paths are used to attach dependency errors to concrete files for users.